<?php
//
register_nav_menu('main-menu', 'Main Menu');



// Add Google Fonts
function startwordpress_google_fonts() {
				wp_register_style('OpenSans', '//fonts.googleapis.com/css?family=Open+Sans:400,600,700,800');
				wp_enqueue_style( 'OpenSans');
		}

add_action('wp_print_styles', 'startwordpress_google_fonts');

// WordPress Titles
function startwordpress_wp_title( $title, $sep ) {
	global $paged, $page;
	if ( is_feed() ) {
		return $title;
	} 
	// Add the site name.
	$title .= get_bloginfo( 'name' );
	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title = "$title $sep $site_description";
	}
	return $title;
} 
add_filter( 'wp_title', 'startwordpress_wp_title', 10, 2 );

// Custom settings
function custom_settings_add_menu() {
  add_menu_page( 'Custom Settings', 'Custom Settings', 'manage_options', 'custom-settings', 'custom_settings_page', null, 99);
}
add_action( 'admin_menu', 'custom_settings_add_menu' );

// Create Custom Global Settings
function custom_settings_page() { ?>
	<div class="wrap">
		<h1>Custom Settings</h1>
		<form method="post" action="options.php">
			<?php
           settings_fields('section');
           do_settings_sections('theme-options');      
           submit_button(); 
       ?>
		</form>
	</div>
	<?php }

// Twitter
function setting_twitter() { ?>
		<input type="text" name="twitter" id="twitter" value="<?php echo get_option('twitter'); ?>" />
		<?php }

function setting_github() { ?>
			<input type="text" name="github" id="github" value="<?php echo get_option('github'); ?>" />
			<?php }

function setting_facebook() { ?>
			<input type="text" name="facebook" id="facebook" value="<?php echo get_option('facebook'); ?>" />
			<?php }

function custom_settings_page_setup() {
  add_settings_section('section', 'All Settings', null, 'theme-options');
  add_settings_field('twitter', 'Twitter URL', 'setting_twitter', 'theme-options', 'section');
  add_settings_field('github', 'GitHub URL', 'setting_github', 'theme-options', 'section');
  add_settings_field('facebook', 'Facebook URL', 'setting_facebook', 'theme-options', 'section');
  register_setting('section', 'twitter');
  register_setting('section', 'github');
  register_setting('section', 'facebook');
}
add_action( 'admin_init', 'custom_settings_page_setup' );

// Support Featured Images
add_theme_support( 'post-thumbnails' );

// Custom Post Type
function create_my_custom_post() {
	register_post_type('my-custom-post',
			array(
			'labels' => array(
					'name' => __('My Custom Post'),
					'singular_name' => __('My Custom Post'),
			),
			'public' => true,
			'has_archive' => true,
			'supports' => array(
					'title',
					'editor',
					'thumbnail',
				  'custom-fields'
			)
	));
}
add_action('init', 'create_my_custom_post'); 

// Register sidebars. Once registered, widgets can be added to them, as well as custom code.
$sidebar = array(
	'name' => 'Search',
	'id'   => 'search',
	'description' => 'Search.'
);
register_sidebar($sidebar);

/* Support post formats */
add_theme_support( 'post-formats', array( 'gallery', 'image', 'video', 'audio' ) );
/* Here is a nice reference for post formats:
https://www.elegantthemes.com/blog/tips-tricks/how-to-create-wordpress-post-formats
*/

/* bm This is added to remove auto paragraph functionality in content, a feature which 
causes problems for html within content of the carousel. Note that html in content is 
NOT encouraged, but sometimes is a useful workaround when the php equiv in the template 
will be awkward. */
remove_filter('the_content','wp-autop');
remove_filter('the_excerpt','wp-autop');

// Add scripts and stylesheets
// Quiz question - how do you conditionally enqueue bootstrap.js
function register_bootstrap_scripts() {
	wp_enqueue_style( 'bootstrap_css', get_template_directory_uri() . '/css/bootstrap.css', array(), '3.3.7' );
	wp_enqueue_style( 'blog_css', get_template_directory_uri() . '/css/blog.css' );
	wp_enqueue_style( 'carousel_css', get_template_directory_uri() . '/css/carousel.css' );
	wp_enqueue_style( 'menu_css', get_template_directory_uri() . '/css/menu.css' );
	wp_enqueue_script( 'bootstrap_js', get_template_directory_uri() . '/js/bootstrap.min.js', array('jquery'), '3.3.6', true );
	wp_enqueue_script( 'carousel_js', get_template_directory_uri() . '/js/carousel.js', array('jquery'), '3.3.6', true );
	wp_enqueue_script( 'menu_js', get_template_directory_uri() . '/js/menu.js', array('jquery'), '3.3.6', true );
}

add_action( 'wp_enqueue_scripts', 'register_bootstrap_scripts' );

function conditionally_enqueue() {
	/* only activate p5 and your p5 sketches on the page named p5 */
    if ( is_page('p5')){
        wp_enqueue_script( 'p5', get_template_directory_uri() . '/js/p5.min.js' , array('jquery') );
        wp_enqueue_script( 'sketch', get_template_directory_uri() . '/js/ronald/sketch.js' , array('jquery') );
    }
    if ( is_page( 'about' ) ) {
    	// conditionally enqueue css and javascript just for this page.
    }
}
add_action( 'wp_enqueue_scripts', 'conditionally_enqueue' );

wp_enqueue_script( 'ajax-script', get_template_directory_uri() . '/js/ajax.js' , array('jquery') );

// in JavaScript, object properties are accessed as ajax_object.ajax_url, ajax_object.values
wp_localize_script( 'ajax-script', 'ajax_object',array( 'ajax_url' => admin_url( 'admin-ajax.php' )) );

// Add handler function... This links the 'action' in ajax.js to the functions.php file
add_action( 'wp_ajax_send_contact', 'send_contact' );

/* This example assumes that this file has been enqueued and launched from a 
form that has the name, email, subject and message input fields. Copy the following 
to a post and then enqueue the ajax file in functions with a jQuery dependency
<div class="contact">Name</div><input id="name"/>
<div class="contact">Email Address</div><input id="email" type="text" name="email" />
<div class="contact">Subject</div><input id="subject" type="text" name="subject" />
<div class="contact">Message</div><textarea id="message"></textarea>
<a id="submitButton" href="JavaScript: sendContact();" >Submit</a></h3></div>
<div id="contact-result"></div>
*/
/* // Beginning of code to add to functions.php
wp_enqueue_script( 'ajax-script', get_template_directory_uri() . '/js/ajax.js' , array('jquery') );

// in JavaScript, object properties are accessed as ajax_object.ajax_url, ajax_object.values
wp_localize_script( 'ajax-script', 'ajax_object',array( 'ajax_url' => admin_url( 'admin-ajax.php' )) );

// Add handler function... This links the 'action' in ajax.js to the functions.php file
add_action( 'wp_ajax_send_contact', 'send_contact' );
*/

/* This example assumes that this file has been enqueued and launched from a 
form that has the name, email, subject and message input fields. Copy the following 
to a post and then enqueue the ajax file in functions with a jQuery dependency
<div class="contact">Name</div><input id="name"/>
<div class="contact">Email Address</div><input id="email" type="text" name="email" />
<div class="contact">Subject</div><input id="subject" type="text" name="subject" />
<div class="contact">Message</div><textarea id="message"></textarea>
<a id="submitButton" href="JavaScript: sendContact();" >Submit</a></h3></div>
<div id="contact-result"></div>
*/
/* // Beginning of code to add to functions.php
wp_enqueue_script( 'ajax-script', get_template_directory_uri() . '/js/ajax.js' , array('jquery') );

// in JavaScript, object properties are accessed as ajax_object.ajax_url, ajax_object.values
wp_localize_script( 'ajax-script', 'ajax_object',array( 'ajax_url' => admin_url( 'admin-ajax.php' )) );

// Add handler function... This links the 'action' in ajax.js to the functions.php file
add_action( 'wp_ajax_send_contact', 'send_contact' );
*/

function send_contact(){
	$sName = $_REQUEST['name'];
	$sEmail = $_REQUEST['email'];
	$sMessage = $_REQUEST['message'];
	$sSubject = $_REQUEST[''];
	echo("send_contact has received a message from: ". $sName .". The message is - ".$sMessage);
	wp_die();
}

?>